import { AxiosError } from 'axios'
import { useQuery as useRQ, UseQueryOptions } from 'react-query'
import { Implementation, Report } from 'src/models'

import axiosService from 'src/services/axios-service'

export namespace GetReportsByImplementationIdQuery {
  export type Params = { id: Implementation['id'] }

  export type Response = Report[]

  export const key = ['implementations', 'reports']

  export const getKey = (params: Params) => [...key, params]

  export const queryFn = (params: Params) =>
    axiosService
      .get<Response>(`/implementations/${params.id}/reports`)
      .then((res) => res.data)

  export const useQuery = <Select = Response>(
    params: Params,
    options: UseQueryOptions<Response, AxiosError, Select> = {}
  ) => {
    return useRQ(getKey(params), () => queryFn(params), {
      ...options,
    })
  }
}
